# Приложение для нахождения минимальной подсети

Приложение для нахождения минимальной подсети для заданного набора IP-адресов.

## Оценки временной эффективности

Алгоритм обработки IP-адресов и нахождения минимальной подсети включает следующие шаги:

1. **Фильтрация и валидация IP-адресов**: Время выполнения зависит от количества предоставленных IP-адресов. Эффективность `O(n)`, где `n` - количество IP-адресов.

2. **Преобразование IP-адресов в двоичный формат и нахождение общего префикса**: Время выполнения пропорционально количеству IP-адресов и их длине в битах. Эффективность `O(n * m)`, где `n` - количество адресов, `m` - количество бит в адресе (32 для IPv4 и 128 для IPv6).

3. **Создание и возвращение строки подсети**: Этот шаг выполняется за постоянное время `O(1)`, поскольку он связан с операцией форматирования строки на основе уже полученного общего префикса.

В целом, временная эффективность алгоритма может быть оценена как `O(n * m)`

## Способы запуска

### Зависимости

Приложение выполнено на Python версии 3.6.15

Для установки необходимых зависимостей выполните команду:

`pip install -r requirements.txt`

### Запуск из командной строки

1. Клонируйте репозиторий или загрузите исходный код программы на ваш компьютер.

2. Откройте терминал или командную строку и перейдите в директорию с программой.

3. Файлы с IP-адресами для запуска программы находятся в папке data.

4. Запустите программу командой:

   `python main.py data/ipv4_multiple_ips.txt 4`

   где `data/ipv4_multiple_ips.txt` это путь к файлу, а `4` это версия IPv4

### Тестирование

C приложением поставляются тесты для проверки корректности работы.

Тесты расположены в файлах [test_ipv4_utils.py](test_ipv4_utils.py) и [test_ipv6_utils.py](test_ipv6_utils.py)

Программа распознает и прекращает работу если в файле будут некорректные IP-адреса, адреса содержащие буквы или символы.

### Использование Coverage

Для анализа покрытия кода тестами с помощью coverage, выполните следующие команды в терминале:

- Запуск тестов с измерением покрытия:

  `coverage run -m unittest discover`

- Отображение отчета о покрытии в терминале:

  `coverage report`

<img alt="Демо" height="200" src="Терминал.png" width="300"/>

- Генерация HTML-отчета о покрытии:

  `coverage html`

<img alt="Демо" height="200" src="html.png" width="400"/>

HTML-отчет будет сохранен в директории htmlcov/ и может быть просмотрен в браузере.

### Обязательные требования:

`+` Наборы IP-адресов хранятся в текстовых файлах (отдельно для IPv4 и IPv6).

`+` Программа запускается через командную строку (CLI), принимая в качестве параметров имя файла с IP-адресами и версию IP.

`+` Используемые функции и алгоритмы снабжены информативными комментариями.

`+` Тесты оформлены в отдельном файле.

`+` Документация в виде README.md файла содержит оценки временнОй эффективности используемого алгоритма и описание способов запуска программы.

`+` Соответствие кода PEP8 и использование аннотаций типов.

`+` Использование внешних зависимостей (модулей, не входящих в стандартную библиотеку) свести к минимуму.

`+` Тестовое покрытие оценивать не обязательно, но желательно.

`+` Язык программирования – Python (версия не старше 3.6).

`+` Исходный код должен быть опубликован на Github/Gitlab/Bitbucket.

`-` (Будет плюсом) создание установочного пакета с setuptools.
